document.addEventListener('DOMContentLoaded', function() {
  const template1Input = document.getElementById('template1');
  const template2Input = document.getElementById('template2');
  const template3Input = document.getElementById('template3');
  const saveButton = document.getElementById('save');
  const insert1Button = document.getElementById('insert1');
  const insert2Button = document.getElementById('insert2');
  const insert3Button = document.getElementById('insert3');
  const statusDiv = document.getElementById('status');


  // Load saved templates
  chrome.storage.sync.get(['template1', 'template2', 'template3'], function(data) {
    if (data.template1) template1Input.value = data.template1;
    if (data.template2) template2Input.value = data.template2;
    if (data.template3) template3Input.value = data.template3;
  });

  // Save templates
  saveButton.addEventListener('click', function() {
    chrome.storage.sync.set({
      template1: template1Input.value,
      template2: template2Input.value,
      template3: template3Input.value
    }, function() {
      statusDiv.textContent = 'Templates saved!';
      setTimeout(() => statusDiv.textContent = '', 2000); // Clear status after 2 seconds
    });
  });

  // Insert template functions.  These use scripting.executeScript to
  // interact with the active tab.
  function insertTemplate(templateText) {
    chrome.tabs.query({active: true, currentWindow: true}, function(tabs) {
      chrome.scripting.executeScript({
        target: {tabId: tabs[0].id},
        func: insertTextIntoGmail,
        args: [templateText]
      });
    });
  }

  // Event listeners for insert buttons
  insert1Button.addEventListener('click', function() {
    insertTemplate(template1Input.value);
  });

  insert2Button.addEventListener('click', function() {
    insertTemplate(template2Input.value);
  });

  insert3Button.addEventListener('click', function() {
    insertTemplate(template3Input.value);
  });

  // This function is injected into the Gmail page.  It finds the active
  // compose/reply textarea and inserts the template text.
  function insertTextIntoGmail(text) {
    let activeTextarea = null;

    //Compose New Message
    let textAreas = document.querySelectorAll('textarea');
        for (let ta of textAreas) {
          if(ta.classList.contains("editable")){
            activeTextarea = ta;
            break;
          }
        }
    // Reply in an existing message
    if(!activeTextarea){
        let replyAreas = document.querySelectorAll('div[aria-label="Message Body"]');
        if (replyAreas.length > 0){
            activeTextarea = replyAreas[replyAreas.length-1]
        }
    }

    if (activeTextarea) {
      if(activeTextarea.tagName == "TEXTAREA"){
        activeTextarea.value += text;
        // Trigger input event for Gmail to recognize the change.
        const event = new Event('input', { bubbles: true });
        activeTextarea.dispatchEvent(event);
      }
      else if(activeTextarea.tagName == "DIV"){
        activeTextarea.innerHTML += text.replace(/(?:\r\n|\r|\n)/g, '<br>'); //respects line breaks
      }


    } else {
      console.error('No active compose/reply textarea found.');
    }
  }

});